@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Partition a musical duration into rhythmic phrases
 
-our $VERSION = '0.0815';
+our $VERSION = '0.0817';
 
 use Moo;
 use strictures 2;
@@ -15,12 +15,6 @@ use namespace::clean;
 use constant TICKS => 96;
 
 
-has durations => (
-    is      => 'ro',
-    default => sub { return \%MIDI::Simple::Length },
-);
-
-
 has size => (
     is      => 'ro',
     default => sub { return 4 },
@@ -126,6 +120,13 @@ has verbose => (
     default => sub { return 0 },
 );
 
+# hash reference of duration lengths (keyed by duration name)
+# Default: \%MIDI::Simple::Length
+has _durations => (
+    is      => 'ro',
+    default => sub { return \%MIDI::Simple::Length },
+);
+
 
 sub motif {
     my ($self) = @_;
@@ -212,7 +213,7 @@ sub _duration {
         $dura = $1;
     }
     else {
-        $dura = $self->durations->{$name};
+        $dura = $self->_durations->{$name};
     }
 
     return $dura;
@@ -232,7 +233,7 @@ Music::Duration::Partition - Partition a musical duration into rhythmic phrases
 
 =head1 VERSION
 
-version 0.0815
+version 0.0817
 
 =head1 SYNOPSIS
 
@@ -278,14 +279,6 @@ L<Music::Duration::Partition::Tutorial::Advanced>.
 
 =head1 ATTRIBUTES
 
-=head2 durations
-
-  $durations = $mdp->durations;
-
-A hash reference of duration lengths (keyed by duration name).
-
-Default: C<\%MIDI::Simple::Length>
-
 =head2 size
 
   $size = $mdp->size;
